#
# spec file for package kidentitymanagement
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.3.0
%define qt6_version 6.6.0
%define kpim6_version 6.2.3

%bcond_without released
Name:           kidentitymanagement
Version:        24.08.3
Release:        1.1
Summary:        KDE PIM Libraries: Identity Management
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Codecs) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.11
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6TextCustomEditor)
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(KPim6TextEdit) >= %{kpim6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}

%description
This package provides a library to handle multiple email identities and
associated settings.

%package -n libKPim6IdentityManagementCore6
Summary:        KDE PIM Libraries: Identity Management - core library
Recommends:     kidentitymanagement-lang
Requires:       kidentitymanagement >= %{version}
Obsoletes:      libKF5IdentityManagement5 < %{version}
Obsoletes:      libKPim5IdentityManagement5 < %{version}

%description  -n libKPim6IdentityManagementCore6
This package provides the core library to handle multiple email identities and
associated settings.

%package -n libKPim6IdentityManagementWidgets6
Summary:        KDE PIM Libraries: Identity Management - widgets library
Recommends:     kidentitymanagement-lang
Requires:       libKPim6IdentityManagementCore6 = %{version}
Obsoletes:      libKPim5IdentityManagementWidgets5 < %{version}

%description  -n libKPim6IdentityManagementWidgets6
This package provides graphical widgets to handle multiple email identities
and associated settings.

%package -n libKPim6IdentityManagementQuick6
Summary:        KDE PIM Libraries: Identity Management - QtQuick library
Requires:       libKPim6IdentityManagementCore6 = %{version}

%description -n libKPim6IdentityManagementQuick6
This package provides a shared library to build QtQuick interfaces for 
PIM identity management.

%package imports
Summary:        QML imports for using kidentitymanagement
Requires:       libKPim6IdentityManagementCore6 = %{version}
Requires:       libKPim6IdentityManagementQuick6 = %{version}

%description imports
QML imports for using kidentitymanagement.

%package devel
Summary:        KDE PIM Libraries: Identity Management - development files
Requires:       libKPim6IdentityManagementCore6 = %{version}
Requires:       libKPim6IdentityManagementWidgets6 = %{version}
Requires:       libKPim6IdentityManagementQuick6 = %{version}
Requires:       cmake(KF6CoreAddons) >= %{kf6_version}
Requires:       cmake(KPim6TextEdit) >= %{kpim6_version}

%description devel
This package contains necessary include files and libraries needed
to develop applications that make use of multiple email identities.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%ldconfig_scriptlets -n libKPim6IdentityManagementCore6
%ldconfig_scriptlets -n libKPim6IdentityManagementWidgets6
%ldconfig_scriptlets -n libKPim6IdentityManagementQuick6

%files
%{_kf6_debugdir}/kidentitymanagement.categories
%{_kf6_debugdir}/kidentitymanagement.renamecategories

%files -n libKPim6IdentityManagementCore6
%license LICENSES/*
%{_kf6_libdir}/libKPim6IdentityManagementCore.so.*

%files -n libKPim6IdentityManagementWidgets6
%{_kf6_libdir}/libKPim6IdentityManagementWidgets.so.*

%files -n libKPim6IdentityManagementQuick6
%{_kf6_libdir}/libKPim6IdentityManagementQuick.so.*

%files imports
%{_kf6_qmldir}/org/kde/kidentitymanagement/

%files devel
%doc %{_kf6_qchdir}/KPim6IdentityManagement*.*
%{_includedir}/KPim6/KIdentityManagementCore/
%{_includedir}/KPim6/KIdentityManagementQuick/
%{_includedir}/KPim6/KIdentityManagementWidgets/
%{_kf6_cmakedir}/KPim6IdentityManagementCore/
%{_kf6_cmakedir}/KPim6IdentityManagementQuick/
%{_kf6_cmakedir}/KPim6IdentityManagementWidgets/
%{_kf6_dbusinterfacesdir}/kf6_org.kde.pim.IdentityManager.xml
%{_kf6_libdir}/libKPim6IdentityManagementCore.so
%{_kf6_libdir}/libKPim6IdentityManagementQuick.so
%{_kf6_libdir}/libKPim6IdentityManagementWidgets.so

%files lang -f %{name}.lang

%changelog
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Qml: Fix deleting identity
  * Qml: Close identity editor after deleting identity
  * Qml: add field for changing identity name
  * Fix cmake lint warning
  * USe @action:button
  * Add build-ftime support
  * Use context i18n
  * add missing [[nodiscard]]
  * Add Q_OBJECT
  * Improve autotests
  * Hide ActivitiesRole column
  * Fix typo
  * It compiles fine without deprecated kf methods
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Search Qt6DBus
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Too many changes to list here.
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
- Uninstall old KDE PIM 5 libraries (boo#1221515)
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- Changes since 24.01.95:
  * Missing -o => we didn't extract string from qml
* Fri Feb  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- No code change since 23.08.2
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Fix platforms info
  * Remove CI 6 job. We will use kf6 branch for kf6 works
  * not export symbol of private methods
  * Use correct INSTALL_TARGETS_DEFAULT_ARGS
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Use correct INSTALL_TARGETS_DEFAULT_ARGS
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * Fix compile without deprecated method
  * Remove namespace include dirs from include search paths
  * Fix message extraction
  * Split KIdentityManagement into a core and widgets library
  * Forward error messages from command signatures to the consumer
  * Determine embedded images without depending on a rich text widget
  * Remove insertIntoTextEdit() from Signature's public interface
  * Use upper case include
  * Add qt6 gitlab support
  * Install *_version.h in KF5/<module>
  * Adapt build system for building against qt6
  * Help to make it compile against qt6
  * Correct prefix to other PIM repositories in .kde-ci.yml
  * Warning--
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- Changes since 21.11.90:
  * Enable new GitLab CI on stable branch.
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- No code change since 21.11.80
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Allow to show header in qtc6
  * Use unique_ptr here
  * Revert this part it breaks messagelib build
  * Fix some cppcheck
  * Use QVERIFY + operator !=
  * Add support for storing Face header
  * Remove some qOverload as we remove deprecated qt5.15 signal
  * Add KDE CI file
  * Use qOverload directly (scripted)
  * Const'ify variable + use explicit
  * Rename method as I asked on MR but didn't do. + make method working
  * Fix compile.
  * Add api to show (default) in combobox
  * Add isDefaultIdentity to IdentifyCombobox
  * Fix version
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Fix Bug 439786 - Folder default identity not applied
    if identity UOID > 0x7fffffff (kde#439786)
  * Modernize code
  * Remove this forward declaration we already include
  * In kf6 kde4 migrate code will be removed
  * Assign directly
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- No code change since 21.03.80
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * Fix Bug 430398 - cmake searches unused dependency (kde#430398)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- No code change since 20.12.2
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * Modernize code
  * Fix generate pri file
  * Clean up
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * Time to increase version
  * Add missing Q_REQUIRED_RESULT
  * modernize code
  * Convert license headers to SPDX format
  * increase dependancy
  * Make it compile with last kpimtextedit
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Changes since 20.04.3:
  * Const'ify
  * Fix coding style
  * Port to QRandomGenerator from KRandom::random
  * We depend against kf5.71
  * USe QVector
  * Add missing Q_REQUIRED_RESULT
  * Make it compile against 5.71 without deprecated method
  * Fix error during merging
  * Use QLatin1Char('/') here
  * Fix includes. Use uppercase includes
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Downgrade "There was no default identity" warning to debug
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Qt guys reverted api in qt5.15
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Changes since 19.12.3:
  * Make it compile against qt5.15
  * Autogenerate categories file
  * Make it compiles against qt5.15 (endl other other use Qt:: namespace now)
  * Use CamelCase header
  * Remove QCombobox usage
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- No code change since 19.12.2
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Check if 'cat' executable exists before using it
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Check if 'cat' executable exists before using it
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Warn if emailsidentity we can't write in this config file
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * Add dummy API docs, so these classes show up on api.kde.org
- Remove outdated version requirements
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- No code change since 19.08.1
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Include KDE* cmake macros before any others
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * When we use framework 5.59.0 we can use new logging file directory
  * Fix the build
  * USe QVector
  * It was fixed in 5.13.0beta2
  * metainfo.yaml: Fix cmakename, is own top-level entry
  * Second attempt on getting API docs generated on api.kde.org
  * Add to kdepim group so this shows up on api.kde.org
  * Fix compile: replace foreach with std::remove_if + erase
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Fix Bug 391631 - Identity not in list after creation (kde#391631)
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Fix the kcoreaddons detection with older CMake versions.
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * Make it compile when we have kf5 < 5.57 (FOREACH)
  * Convert to camelcase include
  * Fix compile: replace foreach with std::remove_if + erase
  * Workaround qt5.13 bug
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Fix compile with Qt 5.13 and QT_DISABLE_DEPRECATED_BEFORE=0x060000
  * Fix minor typos
  * Fix whatsthis
  * Fix some clazy warning
  * Fix minor typos
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix show error as utf8
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Don't show dialogbox when we open configurator
  * Add warning if signature file text is too big
  * Rename slot
  * Reduce type of file to txt file
  * Define type of files
  * QT_NO_NARROWING_CONVERSIONS_IN_CONNECT is defined in kf5.51
  * Use new syntax
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Add signal when identity is not found
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * USe Q_REQUIRED_RESULT
  * Don't use deprecated api
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * None
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Add renamecategories
  * Fix some warnings
  * Use override directly
  * Use QLatin1String
- Fix descriptions
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * None
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Emit identity deleted
  * USe QStringLiteral
  * Fix error found by cppcheck
  * Convert to new connect api
  * Clean up
  * Use new connect api
  * Move in cpp file
  * Generate test images ourselves, don't rely on icons being installed
  * Fix includes
  * Fix forward declaration
  * Fix typo
  * initialize variables
  * Allow to run test without install it
  * Remove deprecated method
  * Not necessary to use KComboBox here.
  * Use qoverload
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Add more definitions QT_NO_URL_CAST_FROM_STRING
  * tests: fix signature from command w/ spaces in path
  * Don't use deprecated method
  * Coding style
  * Remove not necessary check
  * Activate by default QT_NO_NARROWING_CONVERSIONS_IN_CONNECT
  * use nullptr
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Fix potential crash
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Simplify create folder
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Simplify create folder
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Fix indent
  * Clean up
  * use for(...:...)
  * Minor optimization
  * Port to for(...:..)
  * Add ECMCoverageOption
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Sat Jul 16 2016 wbauer@tmo.at
- Cleanup build requirements
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Fri Dec 11 2015 p.drouand@gmail.com
- Remove superfluous libpth-devel dependency
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Initial version based on KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
